coef.boostrq: estimated coefficients of boosting regression quantiles
Description
estimated coefficients of boosting regression quantiles
Usage
# S3 method for boostrq
coef(object, which = NULL, aggregate = "sum", ...)
Value
coef extracts the regression coefficients of the fitted boostrq model.
Arguments
object
object of class boostrq
which
a subset of base-learners
aggregate
a character specifying how to aggregate coefficients of
single base learners. The default returns the coefficient for the final number
of boosting iterations. "cumsum" returns a list with matrices (one per base-learner)
with the cumulative coefficients for all iterations. "none" returns a list of
matrices where the jth columns of the respective matrix contains coefficients
of the base-learner of the jth boosting iteration.v "sum_aggr" ...